summaryrefslogtreecommitdiff
path: root/tests/mutex7e.c
diff options
context:
space:
mode:
Diffstat (limited to 'tests/mutex7e.c')
-rw-r--r--tests/mutex7e.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/tests/mutex7e.c b/tests/mutex7e.c
index 5b8e68f..8d3a2d3 100644
--- a/tests/mutex7e.c
+++ b/tests/mutex7e.c
@@ -37,7 +37,7 @@
*
* Tests PTHREAD_MUTEX_ERRORCHECK mutex type.
* Thread locks and then trylocks mutex (attempted recursive lock).
* Trylock should fail with an EDEADLK error.
* The second unlock attempt should fail with an EPERM error.
*
* Depends on API functions:
@@ -64,7 +64,7 @@ void * locker(void * arg)
{
assert(pthread_mutex_lock(&mutex) == 0);
lockCount++;
- assert(pthread_mutex_trylock(&mutex) == EDEADLK);
+ assert(pthread_mutex_trylock(&mutex) == EBUSY);
lockCount++;
assert(pthread_mutex_unlock(&mutex) == 0);
assert(pthread_mutex_unlock(&mutex) == EPERM);
@@ -37,7 +37,7 @@
* Tests PTHREAD_MUTEX_ERRORCHECK mutex type.
* Thread locks and then trylocks mutex (attempted recursive lock).
- * Trylock should fail with an EDEADLK error.
+ * Trylock should fail with an EBUSY error.
* The second unlock attempt should fail with an EPERM error.
*